@@ -79,16 +79,19 @@ getTlsConnection tls sock = do
 getTlsProxyConnection
     :: NC.TLSSettings
     -> Maybe NC.SockSettings
-    -> IO (S.ByteString -> (Connection -> IO ()) -> Maybe HostAddress -> String -> Int -> IO Connection)
+    -> IO (S.ByteString -> (Connection -> IO ()) -> String -> Maybe HostAddress -> String -> Int -> IO Connection)
 getTlsProxyConnection tls sock = do
     context <- NC.initConnectionContext
-    return $ \connstr checkConn _ha host port -> do
+    return $ \connstr checkConn serverName _ha host port -> do
         --error $ show (connstr, host, port)
         conn <- NC.connectTo context NC.ConnectionParams
-            { NC.connectionHostname = host
+            { NC.connectionHostname = serverName
             , NC.connectionPort = fromIntegral port
             , NC.connectionUseSecure = Nothing
-            , NC.connectionUseSocks = sock
+            , NC.connectionUseSocks =
+                case sock of
+                    Just _ -> error "Cannot use SOCKS and TLS proxying together"
+                    Nothing -> Just $ NC.OtherProxy host $ fromIntegral port
             }
 
         NC.connectionPut conn connstr
